@@ -4,8 +4,7 @@
  * SPDX-License-Identifier: LGPL-2.1+
  */
 
-#ifndef __FWUPD_CLIENT_H
-#define __FWUPD_CLIENT_H
+#pragma once
 
 #include <glib-object.h>
 #include <gio/gio.h>
@@ -79,6 +78,10 @@ gboolean	 fwupd_client_unlock			(FwupdClient	*client,
 							 const gchar	*device_id,
 							 GCancellable	*cancellable,
 							 GError		**error);
+gboolean	 fwupd_client_activate			(FwupdClient	*client,
+							 GCancellable	*cancellable,
+							 const gchar	*device_id,
+							 GError		**error);
 gboolean	 fwupd_client_clear_results		(FwupdClient	*client,
 							 const gchar	*device_id,
 							 GCancellable	*cancellable,
@@ -116,6 +119,7 @@ gboolean	 fwupd_client_modify_device		(FwupdClient	*client,
 							 GCancellable	*cancellable,
 							 GError		**error);
 FwupdStatus	 fwupd_client_get_status		(FwupdClient	*client);
+gboolean	 fwupd_client_get_tainted		(FwupdClient	*client);
 guint		 fwupd_client_get_percentage		(FwupdClient	*client);
 const gchar	*fwupd_client_get_daemon_version	(FwupdClient	*client);
 
@@ -127,7 +131,17 @@ FwupdRemote	*fwupd_client_get_remote_by_id		(FwupdClient	*client,
 							 GCancellable	*cancellable,
 							 GError		**error);
 
+gchar		**fwupd_client_get_approved_firmware	(FwupdClient	*client,
+							 GCancellable	*cancellable,
+							 GError		**error);
+gboolean	 fwupd_client_set_approved_firmware	(FwupdClient	*client,
+							 gchar		**checksums,
+							 GCancellable	*cancellable,
+							 GError		**error);
+gchar		*fwupd_client_self_sign			(FwupdClient	*client,
+							 const gchar	*value,
+							 FwupdSelfSignFlags flags,
+							 GCancellable	*cancellable,
+							 GError		**error);
+
 G_END_DECLS
-
-#endif /* __FWUPD_CLIENT_H */
-
